@@ -1,5 +1,5 @@
 package Yahoo::Marketing::HistoricalRequestData;
-# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -8,17 +8,19 @@ use base qw/Yahoo::Marketing::ComplexType/;
 
 =head1 NAME
 
-Yahoo::Marketing::HistoricalRequestData - an object represents the keyword data or metrics on which a historical retroactive forecast is required. 
+Yahoo::Marketing::HistoricalRequestData - an object to represent a Yahoo Marketing HistoricalRequestData.
 
 =cut
 
 sub _user_setable_attributes {
     return ( qw/ 
-             accountID
-             endDate
-             marketID
-             matchTypes
-             startDate
+                 accountID
+                 endDate
+                 marketID
+                 matchType
+                 startDate
+                 targetingAttributes
+                 targetingProfile
             /  );
 }
 
@@ -35,17 +37,17 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V5/reference/dataObjects.php> for documentation of the various data objects.
 
 
-=head2 new
-
-Creates a new instance
-
 =cut
 
 =head1 METHODS
 
+=head2 new
+
+Creates a new instance
+
 =head2 get/set methods
 
 =over 8
@@ -53,8 +55,10 @@ Creates a new instance
     accountID
     endDate
     marketID
-    matchTypes
+    matchType
     startDate
+    targetingAttributes
+    targetingProfile
 
 =back
 
